=== modified file 'configure.ac'
--- configure.ac	2010-12-19 16:20:13 +0000
+++ configure.ac	2011-01-23 21:32:31 +0000
@@ -83,7 +83,7 @@
 AC_DEFINE([BUILDING_DRIZZLED],[1],
           [Define indicating we are building and not consuming drizzle.])
 
-PANDORA_HAVE_LIBGTEST
+PANDORA_HAVE_BOOST_TEST
 PANDORA_HAVE_LIBSQLITE3
 
 AC_CHECK_FUNC(inet_ntoa, [], [AC_CHECK_LIB(nsl, inet_ntoa)])

=== added file 'm4/pandora_have_libboost_test.m4'
--- m4/pandora_have_libboost_test.m4	1970-01-01 00:00:00 +0000
+++ m4/pandora_have_libboost_test.m4	2011-01-23 21:32:31 +0000
@@ -0,0 +1,45 @@
+dnl Copyright (C) 2011 Andrew Hutchings
+dnl This file is free software; Andrew Hutchings
+dnl gives unlimited permission to copy and/or distribute it,
+dnl with or without modifications, as long as this notice is preserved.
+
+AC_DEFUN([_PANDORA_SEARCH_BOOST_TEST],[
+  AC_REQUIRE([AC_LIB_PREFIX])
+
+  dnl --------------------------------------------------------------------
+  dnl  Check for boost::test
+  dnl --------------------------------------------------------------------
+
+  AC_LANG_PUSH(C++)
+  AC_LIB_HAVE_LINKFLAGS(boost_unit_test_framework-mt,,[
+    #include <boost/test/unit_test.hpp>
+  ],[
+    boost::unit_test::unit_test_log.set_threshold_level(boost::unit_test::log_messages);
+  ])
+  AS_IF([test "x${ac_cv_libboost_test_framework_mt}" = "xno"],[
+    AC_LIB_HAVE_LINKFLAGS(boost_unit_test_framework,,[
+      #include <boost/test/unit_test.hpp>
+    ],[
+      boost::unit_test::unit_test_log.set_threshold_level(boost::unit_test::log_messages);
+    ])
+  ])
+  AC_LANG_POP()
+  
+  AM_CONDITIONAL(HAVE_BOOST_TEST,
+    [test "x${ac_cv_libboost_test_framework}" = "xyes" -o "x${ac_cv_libboost_test_framework_mt}" = "xyes"])
+  BOOST_LIBS="${BOOST_LIBS} ${LTLIBBOOST_TEST_MT} ${LTLIBBOOST_TEST}"
+  AC_SUBST(BOOST_LIBS) 
+])
+
+AC_DEFUN([PANDORA_HAVE_BOOST_TEST],[
+  PANDORA_HAVE_BOOST($1)
+  _PANDORA_SEARCH_BOOST_TEST($1)
+])
+
+AC_DEFUN([PANDORA_REQUIRE_BOOST_TEST],[
+  PANDORA_REQUIRE_BOOST($1)
+  _PANDORA_SEARCH_BOOST_TEST($1)
+  AS_IF([test "x${ac_cv_libboost_test_framework}" = "xno" -a "x${ac_cv_libboost_test_framework_mt}" = "xno"],
+      AC_MSG_ERROR([boost::test is required for ${PACKAGE}]))
+])
+

=== modified file 'unittests/atomics_test.cc'
--- unittests/atomics_test.cc	2011-01-20 17:22:18 +0000
+++ unittests/atomics_test.cc	2011-01-23 21:32:31 +0000
@@ -19,7 +19,8 @@
  */
 
 #include "config.h"
-#include <boost/test/included/unit_test.hpp>
+#define BOOST_TEST_DYN_LINK
+#include <boost/test/unit_test.hpp>
 
 #include <drizzled/atomics.h>
 

=== modified file 'unittests/calendar_test.cc'
--- unittests/calendar_test.cc	2011-01-20 17:22:18 +0000
+++ unittests/calendar_test.cc	2011-01-23 21:32:31 +0000
@@ -19,8 +19,8 @@
  */
 
 #include "config.h"
-
-#include <boost/test/included/unit_test.hpp>
+#define BOOST_TEST_DYN_LINK
+#include <boost/test/unit_test.hpp>
 
 #include <drizzled/calendar.h>
 

=== added file 'unittests/constrained_value.cc'
--- unittests/constrained_value.cc	1970-01-01 00:00:00 +0000
+++ unittests/constrained_value.cc	2011-01-23 21:32:31 +0000
@@ -0,0 +1,58 @@
+/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Monty Taylor
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#include <string>
+
+#define BOOST_TEST_DYN_LINK
+#include <boost/test/unit_test.hpp>
+
+#include <drizzled/constrained_value.h>
+#include <boost/lexical_cast.hpp>
+
+using namespace drizzled;
+
+namespace po= boost::program_options;
+
+BOOST_AUTO_TEST_SUITE(ConstrainedValue)
+BOOST_AUTO_TEST_CASE(raw_usage)
+{
+  constrained_check<uint64_t,1024,1,10> val(1);
+
+  BOOST_REQUIRE_EQUAL(UINT64_C(1), (uint64_t)val);
+
+  BOOST_REQUIRE_THROW(val= 1025 , po::validation_error);
+  BOOST_REQUIRE_THROW(val= 0 , po::validation_error);
+
+  val= 25;
+
+  BOOST_REQUIRE_EQUAL(20, (uint64_t)val);
+}
+
+BOOST_AUTO_TEST_CASE(lexical_cast_usage)
+{
+  constrained_check<uint64_t,1024,1,10> val(1);
+
+  std::string string_val= boost::lexical_cast<std::string>(val);
+
+  BOOST_REQUIRE_EQUAL(std::string("1"), string_val);
+}
+BOOST_AUTO_TEST_SUITE_END()

=== added file 'unittests/date_test.cc'
--- unittests/date_test.cc	1970-01-01 00:00:00 +0000
+++ unittests/date_test.cc	2011-01-23 21:32:31 +0000
@@ -0,0 +1,562 @@
+/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Pawel Blokus
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#define BOOST_TEST_DYN_LINK
+#include <boost/test/unit_test.hpp>
+
+#include <drizzled/type/decimal.h>
+#include <drizzled/temporal.h>
+#include <drizzled/temporal_format.h>
+
+#include "temporal_generator.h"
+
+using namespace drizzled;
+
+class DateTestCompareOperators
+{
+ protected:
+  Date sample_date;
+  bool result;
+  
+  Date identical_with_sample_date, before_sample_date, after_sample_date;
+  
+  DateTestCompareOperators()
+  {
+    TemporalGenerator::DateGen::make_date(&sample_date, 2010, 9, 8);
+    TemporalGenerator::DateGen::make_date(&before_sample_date, 1980, 1, 1);
+    TemporalGenerator::DateGen::make_date(&identical_with_sample_date, 2010, 9, 8);
+    TemporalGenerator::DateGen::make_date(&after_sample_date, 2019, 5, 30);
+  }
+};
+
+class DateTimeTestCompareOperators
+{
+ protected:
+  Date sample_date;
+  bool result;
+  
+  DateTime identical_with_sample_date, before_sample_date, after_sample_date;
+  
+  DateTimeTestCompareOperators()
+  {
+    TemporalGenerator::DateGen::make_date(&sample_date, 2010, 9, 8);
+    TemporalGenerator::DateTimeGen::make_datetime(&before_sample_date, 1990, 12, 31, 12, 12, 30);
+    TemporalGenerator::DateTimeGen::make_datetime(&identical_with_sample_date, 2010, 9, 8, 0, 0, 0);
+    TemporalGenerator::DateTimeGen::make_datetime(&after_sample_date, 2020, 4, 4, 4, 4, 4);
+  }
+};
+
+class TimestampTestCompareOperators
+{
+ protected:
+  Date sample_date;
+  bool result;
+  
+  Timestamp identical_with_sample_date, before_sample_date, after_sample_date;
+  
+  TimestampTestCompareOperators()
+  {
+    TemporalGenerator::DateGen::make_date(&sample_date, 2010, 9, 8);
+    TemporalGenerator::TimestampGen::make_timestamp(&before_sample_date, 1980, 1, 1, 13, 56, 41);
+    TemporalGenerator::TimestampGen::make_timestamp(&identical_with_sample_date, 2010, 9, 8, 0, 0, 0);
+    TemporalGenerator::TimestampGen::make_timestamp(&after_sample_date, 2019, 5, 30, 9, 10, 13);
+  }
+};
+
+BOOST_AUTO_TEST_SUITE(DateTestCompare)
+BOOST_FIXTURE_TEST_CASE(operatorComparingDate, DateTestCompareOperators)
+{
+  result= (sample_date == identical_with_sample_date);
+  BOOST_REQUIRE(result);
+
+  result= (sample_date == before_sample_date);  
+  BOOST_REQUIRE(not result);
+
+  result= (sample_date != identical_with_sample_date);
+  BOOST_REQUIRE(not result);
+
+  result= (sample_date != before_sample_date);  
+  BOOST_REQUIRE(result);
+
+  result= (sample_date > identical_with_sample_date);
+  BOOST_REQUIRE(not this->result);
+
+  result= (sample_date > after_sample_date);
+  BOOST_REQUIRE(not result);
+
+  result= (sample_date > before_sample_date);
+  BOOST_REQUIRE(result);
+
+  result= (sample_date >= identical_with_sample_date);
+  BOOST_REQUIRE(result);
+
+  result= (sample_date >= after_sample_date);
+  BOOST_REQUIRE(not result);
+
+  result= (sample_date >= before_sample_date);
+  BOOST_REQUIRE(result);
+
+  result= (sample_date < identical_with_sample_date);
+  
+  BOOST_REQUIRE(not result);
+
+  result= (sample_date < after_sample_date);
+  BOOST_REQUIRE(result);
+
+  result= (sample_date < before_sample_date);
+  BOOST_REQUIRE(not result);
+
+  result= (sample_date <= identical_with_sample_date);
+  BOOST_REQUIRE(result);
+
+  result= (sample_date <= after_sample_date);
+  
+  BOOST_REQUIRE(result);
+
+  result= (sample_date <= before_sample_date);
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_FIXTURE_TEST_CASE(operatorComparingDateTime, DateTimeTestCompareOperators)
+{
+  result= (sample_date == identical_with_sample_date);
+  BOOST_REQUIRE(result);
+
+  result= (sample_date == before_sample_date);  
+  BOOST_REQUIRE(not result);
+
+  result= (sample_date != identical_with_sample_date);
+  BOOST_REQUIRE(not result);
+
+  result= (sample_date != before_sample_date);  
+  BOOST_REQUIRE(result);
+
+  result= (sample_date > identical_with_sample_date);
+  BOOST_REQUIRE(not this->result);
+
+  result= (sample_date > after_sample_date);
+  BOOST_REQUIRE(not result);
+
+  result= (sample_date > before_sample_date);
+  BOOST_REQUIRE(result);
+
+  result= (sample_date >= identical_with_sample_date);
+  BOOST_REQUIRE(result);
+
+  result= (sample_date >= after_sample_date);
+  BOOST_REQUIRE(not result);
+
+  result= (sample_date >= before_sample_date);
+  BOOST_REQUIRE(result);
+
+  result= (sample_date < identical_with_sample_date);
+  
+  BOOST_REQUIRE(not result);
+
+  result= (sample_date < after_sample_date);
+  BOOST_REQUIRE(result);
+
+  result= (sample_date < before_sample_date);
+  BOOST_REQUIRE(not result);
+
+  result= (sample_date <= identical_with_sample_date);
+  BOOST_REQUIRE(result);
+
+  result= (sample_date <= after_sample_date);
+  
+  BOOST_REQUIRE(result);
+
+  result= (sample_date <= before_sample_date);
+  BOOST_REQUIRE(not result);
+}
+
+
+BOOST_FIXTURE_TEST_CASE(operatorComparingTimestamp, TimestampTestCompareOperators)
+{
+  result= (sample_date == identical_with_sample_date);
+  BOOST_REQUIRE(result);
+
+  result= (sample_date == before_sample_date);  
+  BOOST_REQUIRE(not result);
+
+  result= (sample_date != identical_with_sample_date);
+  BOOST_REQUIRE(not result);
+
+  result= (sample_date != before_sample_date);  
+  BOOST_REQUIRE(result);
+
+  result= (sample_date > identical_with_sample_date);
+  BOOST_REQUIRE(not this->result);
+
+  result= (sample_date > after_sample_date);
+  BOOST_REQUIRE(not result);
+
+  result= (sample_date > before_sample_date);
+  BOOST_REQUIRE(result);
+
+  result= (sample_date >= identical_with_sample_date);
+  BOOST_REQUIRE(result);
+
+  result= (sample_date >= after_sample_date);
+  BOOST_REQUIRE(not result);
+
+  result= (sample_date >= before_sample_date);
+  BOOST_REQUIRE(result);
+
+  result= (sample_date < identical_with_sample_date);
+  
+  BOOST_REQUIRE(not result);
+
+  result= (sample_date < after_sample_date);
+  BOOST_REQUIRE(result);
+
+  result= (sample_date < before_sample_date);
+  BOOST_REQUIRE(not result);
+
+  result= (sample_date <= identical_with_sample_date);
+  BOOST_REQUIRE(result);
+
+  result= (sample_date <= after_sample_date);
+  
+  BOOST_REQUIRE(result);
+
+  result= (sample_date <= before_sample_date);
+  BOOST_REQUIRE(not result);
+}
+BOOST_AUTO_TEST_SUITE_END()
+
+
+class DateTest
+{
+  protected:
+    Date date;
+    bool result;
+    
+    DateTest()
+    {
+      TemporalGenerator::DateGen::make_valid_date(&date);
+    }
+};
+
+BOOST_AUTO_TEST_SUITE(CurrentDateValidationTest)
+BOOST_FIXTURE_TEST_CASE(operatorAssign_shouldCopyDateRelatadComponents, DateTest)
+{
+  Date copy= date;
+
+  BOOST_REQUIRE_EQUAL(date.years(), copy.years());
+  BOOST_REQUIRE_EQUAL(date.months(), copy.months());
+  BOOST_REQUIRE_EQUAL(date.days(), copy.days());
+}
+
+BOOST_FIXTURE_TEST_CASE(is_valid_onValidDate_shouldReturn_True, DateTest)
+{
+  result= date.is_valid();
+  BOOST_REQUIRE(result);
+}
+
+BOOST_FIXTURE_TEST_CASE(is_valid_onInvalidDateWithYearBelowMinimum_shouldReturn_False, DateTest)
+{
+  date.set_years(DRIZZLE_MIN_YEARS_SQL - 1);
+  
+  result= date.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_FIXTURE_TEST_CASE(is_valid_onInvalidDateWithYearAboveMaximum_shouldReturn_False, DateTest)
+{
+  date.set_years(DRIZZLE_MAX_YEARS_SQL + 1);
+    
+  result= date.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_FIXTURE_TEST_CASE(is_valid_onInvalidDateWithMonthSetToZero_shouldReturn_False, DateTest)
+{
+  date.set_months(0);
+  
+  result= date.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+
+BOOST_FIXTURE_TEST_CASE(is_valid_onInvalidDateWithMonthAboveMaximum_shouldReturn_False, DateTest)
+{
+  date.set_months(13);
+  
+  result= date.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_FIXTURE_TEST_CASE(is_valid_onInvalidDateWithDaySetToZero_shouldReturn_False, DateTest)
+{
+  date.set_days(0);
+  
+  result= date.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_FIXTURE_TEST_CASE(is_valid_onInvalidDateWithDayAboveDaysInMonth_shouldReturn_False, DateTest)
+{
+  date.set_days(32);
+  
+  result= date.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_FIXTURE_TEST_CASE(is_valid_onInvalidDateWithLeapDayInNonLeapYear_shouldReturn_False, DateTest)
+{
+  TemporalGenerator::TemporalGen::leap_day_in_non_leap_year(&date);
+  
+  result= date.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_FIXTURE_TEST_CASE(is_valid_onValidDateWithLeapDayInLeapYear_shouldReturn_True, DateTest)
+{
+  TemporalGenerator::TemporalGen::leap_day_in_leap_year(&date);
+  
+  result= date.is_valid();
+  
+  BOOST_REQUIRE(result);
+}
+
+BOOST_FIXTURE_TEST_CASE(to_string_shouldProduce_hyphenSeperatedDateElements, DateTest)
+{
+  char expected[Date::MAX_STRING_LENGTH]= "2010-05-01";
+  char returned[Date::MAX_STRING_LENGTH];
+  TemporalGenerator::DateGen::make_date(&date, 2010, 5, 1);
+  
+  date.to_string(returned, Date::MAX_STRING_LENGTH);
+  
+  BOOST_REQUIRE_EQUAL(expected, returned);
+}
+
+BOOST_FIXTURE_TEST_CASE(to_string_nullBuffer_shouldReturnProperLengthAnyway, DateTest)
+{
+  int length= date.to_string(NULL, 0);
+  
+  BOOST_REQUIRE_EQUAL(Date::MAX_STRING_LENGTH - 1, length);  
+}
+
+BOOST_FIXTURE_TEST_CASE(from_string_validString_shouldPopulateCorrectly, DateTest)
+{
+  char valid_string[Date::MAX_STRING_LENGTH]= "2010-05-01";
+  uint32_t years, months, days;
+
+  init_temporal_formats();
+  
+  result= date.from_string(valid_string, Date::MAX_STRING_LENGTH - 1);
+  BOOST_REQUIRE(result);
+  
+  years= date.years();
+  months= date.months();
+  days= date.days();
+
+  deinit_temporal_formats();
+  
+  BOOST_REQUIRE_EQUAL(2010, years);
+  BOOST_REQUIRE_EQUAL(5, months);
+  BOOST_REQUIRE_EQUAL(1, days);
+}
+
+BOOST_FIXTURE_TEST_CASE(from_string_invalidString_shouldReturn_False, DateTest)
+{
+  char valid_string[Date::MAX_STRING_LENGTH]= "2x10-05-01";
+
+  init_temporal_formats();
+  result= date.from_string(valid_string, Date::MAX_STRING_LENGTH - 1);
+  deinit_temporal_formats();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_FIXTURE_TEST_CASE(to_int64_t, DateTest)
+{
+  TemporalGenerator::DateGen::make_date(&date, 2030, 8, 17);
+  int64_t representation;
+  
+  date.to_int64_t(&representation);
+  
+  BOOST_REQUIRE_EQUAL(20300817, representation);
+}
+
+BOOST_FIXTURE_TEST_CASE(to_int32_t, DateTest)
+{
+  TemporalGenerator::DateGen::make_date(&date, 2030, 8, 17);
+  int32_t representation;
+
+  date.to_int32_t(&representation);
+
+  BOOST_REQUIRE_EQUAL(20300817, representation);
+}
+
+BOOST_FIXTURE_TEST_CASE(from_int32_t_shouldPopulateDateCorrectly, DateTest)
+{
+  uint32_t decoded_years, decoded_months, decoded_days;
+
+  date.from_int32_t(20300817);
+  
+  decoded_years= date.years();
+  decoded_months= date.months();
+  decoded_days= date.days();
+  
+  BOOST_REQUIRE_EQUAL(2030, decoded_years);
+  BOOST_REQUIRE_EQUAL(8, decoded_months);
+  BOOST_REQUIRE_EQUAL(17, decoded_days);
+}
+
+BOOST_FIXTURE_TEST_CASE(to_julian_day_number, DateTest)
+{
+  int64_t julian_day;
+  TemporalGenerator::DateGen::make_date(&date, 1999, 12, 31);
+  
+  date.to_julian_day_number(&julian_day);
+  
+  BOOST_REQUIRE_EQUAL(2451544, julian_day);
+}
+
+BOOST_FIXTURE_TEST_CASE(from_julian_day_number, DateTest)
+{
+  int64_t julian_day= 2451544;
+  uint32_t years, months, days;
+   
+  date.from_julian_day_number(julian_day);
+  
+  years= date.years();
+  months= date.months();
+  days= date.days();
+    
+  BOOST_REQUIRE_EQUAL(1999, years);
+  BOOST_REQUIRE_EQUAL(12, months);
+  BOOST_REQUIRE_EQUAL(31, days);
+}
+
+BOOST_FIXTURE_TEST_CASE(to_tm, DateTest)
+{
+  uint32_t years= 2030, months= 8, days= 17;
+  TemporalGenerator::DateGen::make_date(&date, years, months, days);
+  struct tm filled;
+  
+  date.to_tm(&filled);
+  
+  BOOST_REQUIRE_EQUAL(130, filled.tm_year);
+  BOOST_REQUIRE_EQUAL(7, filled.tm_mon);
+  BOOST_REQUIRE_EQUAL(17, filled.tm_mday);
+  BOOST_REQUIRE_EQUAL(0, filled.tm_hour);
+  BOOST_REQUIRE_EQUAL(0, filled.tm_min);
+  BOOST_REQUIRE_EQUAL(0, filled.tm_sec);
+
+  /* TODO: these fail, shouldn't they also be set properly? */
+  /* From Andrew: These fail because Temporal::to_tm doesn't populate them.
+     Does it need to or would we be wasting cycles doing it? */
+
+  BOOST_WARN_EQUAL(228, filled.tm_yday);
+  BOOST_WARN_EQUAL(6, filled.tm_wday);
+  BOOST_WARN_EQUAL(-1, filled.tm_isdst);
+}
+
+BOOST_FIXTURE_TEST_CASE(from_tm, DateTest)
+{
+  uint32_t years, months, days;
+  struct tm from;
+  from.tm_year= 1956 - 1900;
+  from.tm_mon= 2;
+  from.tm_mday= 30;
+  
+  date.from_tm(&from);
+  
+  years= date.years();
+  months= date.months();
+  days= date.days();
+  
+  BOOST_REQUIRE_EQUAL(1956, years);  
+  BOOST_REQUIRE_EQUAL(3, months);
+  BOOST_REQUIRE_EQUAL(30, days);
+}
+
+BOOST_FIXTURE_TEST_CASE(to_time_t, DateTest)
+{
+  time_t time;
+  TemporalGenerator::DateGen::make_date(&date, 1990, 9, 9);
+  
+  date.to_time_t(time);
+  
+  BOOST_REQUIRE_EQUAL(652838400, time);
+}
+
+BOOST_FIXTURE_TEST_CASE(from_time_t, DateTest)
+{
+  uint32_t years, months, days;
+  
+  date.from_time_t(652838400);
+  
+  years= date.years();
+  months= date.months();
+  days= date.days();
+  
+  BOOST_REQUIRE_EQUAL(1990, years);  
+  BOOST_REQUIRE_EQUAL(9, months);
+  BOOST_REQUIRE_EQUAL(9, days);
+}
+
+BOOST_FIXTURE_TEST_CASE(to_decimal, DateTest)
+{
+  drizzled::type::Decimal to;
+  TemporalGenerator::DateGen::make_date(&date, 1987, 5, 6);
+
+  date.to_decimal(&to);
+
+  BOOST_REQUIRE_EQUAL(19870506, to.buf[0]);
+}
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(DateStringTest)
+BOOST_AUTO_TEST_CASE(DateFromStringTest)
+{
+  Date date;
+  const char *valid_strings[]= {"20100607", /* YYYYMMDD */
+                               "06/07/2010",/* MM[-/.]DD[-/.]YYYY (US common format)*/
+                               "10.06.07",/* YY[-/.]MM[-/.]DD */
+                               "10/6/7",/* YY[-/.][M]M[-/.][D]D */
+                               "2010-6-7"/* YYYY[-/.][M]M[-/.][D]D */};
+
+  init_temporal_formats();
+  for (int it= 0; it < 5; it++)
+  {
+    const char *valid_string= valid_strings[it];
+    bool result= date.from_string(valid_string, strlen(valid_string));
+    BOOST_REQUIRE(result);
+    
+    BOOST_REQUIRE_EQUAL(2010, date.years());
+    BOOST_REQUIRE_EQUAL(6, date.months());
+    BOOST_REQUIRE_EQUAL(7, date.days());
+  }
+  deinit_temporal_formats();
+}
+BOOST_AUTO_TEST_SUITE_END()

=== added file 'unittests/date_time_test.cc'
--- unittests/date_time_test.cc	1970-01-01 00:00:00 +0000
+++ unittests/date_time_test.cc	2011-01-23 21:32:31 +0000
@@ -0,0 +1,478 @@
+/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+*  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+*
+*  Copyright (C) 2010 Pawel Blokus
+*
+*  This program is free software; you can redistribute it and/or modify
+*  it under the terms of the GNU General Public License as published by
+*  the Free Software Foundation; either version 2 of the License, or
+*  (at your option) any later version.
+*
+*  This program is distributed in the hope that it will be useful,
+*  but WITHOUT ANY WARRANTY; without even the implied warranty of
+*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+*  GNU General Public License for more details.
+*
+*  You should have received a copy of the GNU General Public License
+*  along with this program; if not, write to the Free Software
+*  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+*/
+
+#include "config.h"
+
+#define BOOST_TEST_DYN_LINK
+#include <boost/test/unit_test.hpp>
+
+#include <drizzled/type/decimal.h>
+#include <drizzled/temporal.h>
+#include <drizzled/temporal_format.h>
+
+#include "temporal_generator.h"
+
+using namespace drizzled;
+
+class DateTimeTest
+{
+  protected:
+    DateTime datetime;
+    bool result;
+    uint32_t years, months, days;
+    uint32_t hours, minutes, seconds;
+    
+    DateTimeTest()
+    {
+      TemporalGenerator::DateTimeGen::make_valid_datetime(&datetime);
+    }
+
+    void assignDateTimeValues()
+    {
+      years= datetime.years();
+      months= datetime.months();
+      days= datetime.days();
+      hours= datetime.hours();
+      minutes= datetime.minutes();
+      seconds= datetime.seconds();
+    }
+};
+
+BOOST_FIXTURE_TEST_SUITE(DateTimeTestValidation, DateTimeTest)
+BOOST_AUTO_TEST_CASE(is_valid_onValidDateTime_shouldReturn_True)
+{
+  result= datetime.is_valid();
+  BOOST_REQUIRE(result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_onInvalidDateTimeWithYearBelowMinimum_shouldReturn_False)
+{
+  datetime.set_years(DRIZZLE_MIN_YEARS_SQL - 1);
+  
+  result= datetime.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_onInvalidDateTimeWithYearAboveMaximum_shouldReturn_False)
+{
+  datetime.set_years(DRIZZLE_MAX_YEARS_SQL + 1);
+    
+  result= datetime.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_onInvalidDateTimeWithMonthSetToZero_shouldReturn_False)
+{
+  datetime.set_months(0);
+  
+  result= datetime.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+
+BOOST_AUTO_TEST_CASE(is_valid_onInvalidDateTimeWithMonthAboveMaximum_shouldReturn_False)
+{
+  datetime.set_months(13);
+  
+  result= datetime.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_onInvalidDateTimeWithDaySetToZero_shouldReturn_False)
+{
+  datetime.set_days(0);
+  
+  result= datetime.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_onInvalidDateTimeWithDayAboveDaysInMonth_shouldReturn_False)
+{
+  datetime.set_days(32);
+  
+  result= datetime.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_onInvalidDateTimeWithLeapDayInNonLeapYear_shouldReturn_False)
+{
+  TemporalGenerator::TemporalGen::leap_day_in_non_leap_year(&datetime);
+  
+  result= datetime.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_onValidDateTimeWithLeapDayInLeapYear_shouldReturn_True)
+{
+  TemporalGenerator::TemporalGen::leap_day_in_leap_year(&datetime);
+  
+  result= datetime.is_valid();
+  
+  BOOST_REQUIRE(result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_onValidMinimalTime_shouldReturn_True)
+{
+  TemporalGenerator::TemporalGen::make_min_time(&datetime);
+  
+  result= datetime.is_valid();
+  
+  BOOST_REQUIRE(result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_onValidMaximalTime_shouldReturn_True)
+{
+  TemporalGenerator::TemporalGen::make_max_time(&datetime);
+  
+  result= datetime.is_valid();
+  
+  BOOST_REQUIRE(result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_onInvalidDateTimeWithHourAboveMaximum23_shouldReturn_False)
+{
+  datetime.set_hours(24);
+  
+  result= datetime.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_onInvalidDateTimeWithMinutesAboveMaximum59_shouldReturn_False)
+{
+  datetime.set_minutes(60);
+  
+  result= datetime.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_onInvalidDateTimeWithSecondsAboveMaximum61_shouldReturn_False)
+{
+  datetime.set_seconds(62);
+  
+  result= datetime.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(to_string_shouldProduce_hyphenSeperatedDateElements_and_colonSeperatedTimeElements)
+{
+  char expected[DateTime::MAX_STRING_LENGTH]= "2010-05-01 08:07:06.123456";
+  char returned[DateTime::MAX_STRING_LENGTH];
+  TemporalGenerator::DateTimeGen::make_datetime(&datetime, 2010, 5, 1, 8, 7, 6, 123456);
+  
+  datetime.to_string(returned, DateTime::MAX_STRING_LENGTH);
+  
+  BOOST_REQUIRE_EQUAL(expected, returned);
+}
+
+BOOST_AUTO_TEST_CASE(to_string_nullBuffer_noMicroSeconds_shouldReturnProperLengthAnyway)
+{
+  int length= datetime.to_string(NULL, 0);
+  
+  BOOST_REQUIRE_EQUAL(DateTime::MAX_STRING_LENGTH - 1 - 7, length);  
+}
+
+BOOST_AUTO_TEST_CASE(to_int64_t)
+{
+  TemporalGenerator::DateTimeGen::make_datetime(&datetime, 2030, 8, 7, 14, 5, 13);
+  int64_t representation;
+
+  datetime.to_int64_t(&representation);
+
+  BOOST_REQUIRE_EQUAL(20300807140513LL, representation);
+}
+
+BOOST_AUTO_TEST_CASE(from_int64_t_no_conversion_format_YYYYMMDDHHMMSSshouldPopulateDateTimeCorrectly)
+{
+  datetime.from_int64_t(20300807140513LL, false);
+  
+  assignDateTimeValues();
+  
+  BOOST_REQUIRE_EQUAL(2030, years);
+  BOOST_REQUIRE_EQUAL(8, months);
+  BOOST_REQUIRE_EQUAL(7, days);
+  BOOST_REQUIRE_EQUAL(14, hours);
+  BOOST_REQUIRE_EQUAL(5, minutes);
+  BOOST_REQUIRE_EQUAL(13, seconds);
+}
+
+BOOST_AUTO_TEST_CASE(from_int64_t_with_conversion_format_YYYYMMDDHHMMSS_yearOver2000)
+{
+  datetime.from_int64_t(20300807140513LL, true);
+  
+  assignDateTimeValues();
+  
+  BOOST_REQUIRE_EQUAL(2030, years);
+  BOOST_REQUIRE_EQUAL(8, months);
+  BOOST_REQUIRE_EQUAL(7, days);
+  BOOST_REQUIRE_EQUAL(14, hours);
+  BOOST_REQUIRE_EQUAL(5, minutes);
+  BOOST_REQUIRE_EQUAL(13, seconds);
+}
+
+BOOST_AUTO_TEST_CASE(from_int64_t_with_conversion_format_YYYYMMDDHHMMSS_yearBelow2000)
+{
+  datetime.from_int64_t(19900807140513LL, true);
+  
+  assignDateTimeValues();
+  
+  BOOST_REQUIRE_EQUAL(1990, years);
+  BOOST_REQUIRE_EQUAL(8, months);
+  BOOST_REQUIRE_EQUAL(7, days);
+  BOOST_REQUIRE_EQUAL(14, hours);
+  BOOST_REQUIRE_EQUAL(5, minutes);
+  BOOST_REQUIRE_EQUAL(13, seconds);
+}
+
+BOOST_AUTO_TEST_CASE(from_int64_t_with_conversion_format_YYMMDDHHMMSS_yearOver2000)
+{
+  datetime.from_int64_t(300807140513LL, true);
+  
+  assignDateTimeValues();
+  
+  BOOST_REQUIRE_EQUAL(2030, years);
+  BOOST_REQUIRE_EQUAL(8, months);
+  BOOST_REQUIRE_EQUAL(7, days);
+  BOOST_REQUIRE_EQUAL(14, hours);
+  BOOST_REQUIRE_EQUAL(5, minutes);
+  BOOST_REQUIRE_EQUAL(13, seconds);
+}
+
+BOOST_AUTO_TEST_CASE(from_int64_t_with_conversion_format_YYMMDDHHMMSS_yearBelow2000)
+{
+  datetime.from_int64_t(900807140513LL, true);
+  
+  assignDateTimeValues();
+  
+  BOOST_REQUIRE_EQUAL(1990, years);
+  BOOST_REQUIRE_EQUAL(8, months);
+  BOOST_REQUIRE_EQUAL(7, days);
+  BOOST_REQUIRE_EQUAL(14, hours);
+  BOOST_REQUIRE_EQUAL(5, minutes);
+  BOOST_REQUIRE_EQUAL(13, seconds);
+}
+
+BOOST_AUTO_TEST_CASE(to_tm)
+{
+  years= 2030, months= 8, days= 17, hours= 14, minutes= 45, seconds= 13;
+  TemporalGenerator::DateTimeGen::make_datetime(&datetime, years, months, days, hours, minutes, seconds);
+  struct tm filled;
+  
+  datetime.to_tm(&filled);
+  
+  BOOST_REQUIRE_EQUAL(2030 - 1900, filled.tm_year);
+  BOOST_REQUIRE_EQUAL(8 - 1, filled.tm_mon);
+  BOOST_REQUIRE_EQUAL(17, filled.tm_mday);
+  BOOST_REQUIRE_EQUAL(14, filled.tm_hour);
+  BOOST_REQUIRE_EQUAL(45, filled.tm_min);
+  BOOST_REQUIRE_EQUAL(13, filled.tm_sec);
+
+  /* TODO:these fail, shouldn't they also be set properly? */
+  BOOST_WARN_EQUAL(228, filled.tm_yday);
+  BOOST_WARN_EQUAL(6, filled.tm_wday);
+  BOOST_WARN_EQUAL(-1, filled.tm_isdst);
+}
+
+BOOST_AUTO_TEST_CASE(to_decimal)
+{
+  drizzled::type::Decimal to;
+  TemporalGenerator::DateTimeGen::make_datetime(&datetime, 1987, 6, 13, 5, 10, 13, 456);
+
+  datetime.to_decimal(&to);
+  
+  BOOST_REQUIRE_EQUAL(19870,to.buf[0]);
+  BOOST_REQUIRE_EQUAL(613051013,to.buf[1]);
+  BOOST_REQUIRE_EQUAL(456000,to.buf[2]);
+}
+BOOST_AUTO_TEST_SUITE_END()
+
+
+class DateTimeFromStringTest
+{
+  protected:
+    static const char* allStrings[];
+    DateTime datetime;
+    bool result;
+    uint32_t years, months, days;
+    uint32_t hours, minutes, seconds;
+
+    DateTimeFromStringTest()
+    {
+      init_temporal_formats();
+    }
+
+    virtual ~DateTimeFromStringTest()
+    {
+      deinit_temporal_formats();
+    }
+
+    virtual int stringCount() { return 0; }
+    virtual const char** strings() { return NULL; }
+
+    void assignDateTimeValues()
+    {
+      years= datetime.years();
+      months= datetime.months();
+      days= datetime.days();
+      hours= datetime.hours();
+      minutes= datetime.minutes();
+      seconds= datetime.seconds();
+    }
+};
+
+const char* DateTimeFromStringTest::allStrings[]= {"NULL"};
+
+
+class DateTimeFromStringFullFormatTest : public DateTimeFromStringTest
+{
+ protected:
+  static const char* allStrings[];
+
+  const char** strings()
+  {
+    return allStrings;
+  }
+  
+  int stringCount()
+  {
+    return 7;
+  }  
+};
+
+const char* DateTimeFromStringFullFormatTest::allStrings[]= {"20100501080706",
+            "2010-05-01 08:07:06",
+            "2010/05/01T08:07:06",
+            "2010.5.1 08:07:06",
+            "10-05-01 08:07:06",
+            "10/5/1 08:07:06",
+            "10.5.1 08:07:06"};
+
+class DateTimeFromStringNoSecondFormatTest : public DateTimeFromStringTest
+{
+ protected:
+  static const char* allStrings[];
+
+  const char** strings()
+  {
+    return allStrings;
+  }
+  
+  int stringCount()
+  {
+    return 6;
+  }
+};
+
+const char* DateTimeFromStringNoSecondFormatTest::allStrings[]= {"2010-05-01 08:07",
+            "2010/05/01 08:07",
+            "2010.5.1 08:07",
+            "10-05-01 08:07",
+            "10/5/1 08:07",
+            "10.5.1 08:07"};
+
+class DateTimeFromStringDateOnlyTest: public DateTimeFromStringTest
+{
+ protected:
+  static const char* allStrings[];
+
+  const char** strings()
+  {
+    return allStrings;
+  }
+  
+  int stringCount()
+  {
+    return 5;
+  }
+};
+
+const char* DateTimeFromStringDateOnlyTest::allStrings[]= {"20100607", /* YYYYMMDD */
+            "06/07/2010",/* MM[-/.]DD[-/.]YYYY (US common format)*/
+            "10.06.07",/* YY[-/.]MM[-/.]DD */
+            "10/6/7",/* YY[-/.][M]M[-/.][D]D */
+            "2010-6-7"/* YYYY[-/.][M]M[-/.][D]D */};
+
+BOOST_AUTO_TEST_SUITE(DateTimeFromStringTestSuite)
+BOOST_FIXTURE_TEST_CASE(from_string_validStringFull, DateTimeFromStringFullFormatTest)
+{
+  for (int it= 0; it < stringCount(); it++)
+  {
+    const char *valid_string= strings()[it];
+
+    result= datetime.from_string(valid_string, strlen(valid_string));
+    BOOST_REQUIRE(result);
+
+    assignDateTimeValues();
+
+    BOOST_REQUIRE_EQUAL(2010, years);
+    BOOST_REQUIRE_EQUAL(5, months);
+    BOOST_REQUIRE_EQUAL(1, days);
+    BOOST_REQUIRE_EQUAL(8, hours);
+    BOOST_REQUIRE_EQUAL(7, minutes);
+    BOOST_REQUIRE_EQUAL(6, seconds);
+  }
+}
+                                          
+BOOST_FIXTURE_TEST_CASE(from_string_validStringNoSecond, DateTimeFromStringNoSecondFormatTest)
+{
+  for (int it= 0; it < stringCount(); it++)
+  {
+    const char *valid_string= strings()[it];
+
+    result= datetime.from_string(valid_string, strlen(valid_string));
+    BOOST_REQUIRE(result);
+
+    assignDateTimeValues();
+
+    BOOST_REQUIRE_EQUAL(2010, years);
+    BOOST_REQUIRE_EQUAL(5, months);
+    BOOST_REQUIRE_EQUAL(1, days);
+    BOOST_REQUIRE_EQUAL(8, hours);
+    BOOST_REQUIRE_EQUAL(7, minutes);
+  }
+}
+
+BOOST_FIXTURE_TEST_CASE(from_string_validStringDateOnly, DateTimeFromStringDateOnlyTest)
+{
+  for (int it= 0; it < stringCount(); it++)
+  {
+    const char *valid_string= strings()[it];
+
+    result= datetime.from_string(valid_string, strlen(valid_string));
+    BOOST_REQUIRE(result);
+
+    assignDateTimeValues();
+
+    BOOST_REQUIRE_EQUAL(2010, years);
+    BOOST_REQUIRE_EQUAL(6, months);
+    BOOST_REQUIRE_EQUAL(7, days);
+  }
+}
+
+BOOST_AUTO_TEST_SUITE_END()

=== added file 'unittests/global_buffer_test.cc'
--- unittests/global_buffer_test.cc	1970-01-01 00:00:00 +0000
+++ unittests/global_buffer_test.cc	2011-01-23 21:32:31 +0000
@@ -0,0 +1,64 @@
+/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Andrew Hutchings
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#define BOOST_TEST_DYN_LINK
+#include <boost/test/unit_test.hpp>
+
+#include "drizzled/global_buffer.h"
+
+BOOST_AUTO_TEST_SUITE(GlobalBufferTests)
+BOOST_AUTO_TEST_CASE(overflow)
+{
+  drizzled::global_buffer_constraint<uint64_t> test_buffer(1024);
+
+  BOOST_REQUIRE(test_buffer.add(512));
+  BOOST_REQUIRE(test_buffer.add(512));
+  BOOST_REQUIRE(not test_buffer.add(1));
+}
+
+BOOST_AUTO_TEST_CASE(subtract)
+{
+  drizzled::global_buffer_constraint<uint64_t> test_buffer(1024);
+
+  BOOST_REQUIRE(test_buffer.add(1024));
+  BOOST_REQUIRE(test_buffer.sub(512));
+  BOOST_REQUIRE(test_buffer.add(512));
+  BOOST_REQUIRE(not test_buffer.add(1));
+}
+
+BOOST_AUTO_TEST_CASE(underflow)
+{
+  drizzled::global_buffer_constraint<uint64_t> test_buffer(1024);
+
+  BOOST_REQUIRE(test_buffer.add(10));
+  BOOST_REQUIRE(not test_buffer.sub(11));
+}
+
+BOOST_AUTO_TEST_CASE(change_max)
+{
+  drizzled::global_buffer_constraint<uint64_t> test_buffer(1024);
+
+  test_buffer.setMaxSize(512);
+
+  BOOST_REQUIRE(not test_buffer.add(513));
+}
+BOOST_AUTO_TEST_SUITE_END()

=== modified file 'unittests/include.am'
--- unittests/include.am	2011-01-20 17:22:18 +0000
+++ unittests/include.am	2011-01-23 21:32:31 +0000
@@ -17,8 +17,9 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-
+if HAVE_BOOST_TEST
 check_PROGRAMS += unittests/unittests
+endif
 
 noinst_HEADERS += \
 		  unittests/plugin/plugin_stubs.h \
@@ -38,9 +39,24 @@
 unittests_unittests_SOURCES = \
                               unittests/main.cc \
 			      unittests/atomics_test.cc \
-			      unittests/calendar_test.cc 
+			      unittests/calendar_test.cc \
+			      unittests/constrained_value.cc \
+			      unittests/date_test.cc \
+			      unittests/date_time_test.cc \
+			      unittests/global_buffer_test.cc \
+			      unittests/libdrizzle_test.cc \
+			      unittests/micro_timestamp_test.cc \
+			      unittests/nano_timestamp_test.cc \
+			      unittests/option_context.cc \
+			      unittests/pthread_atomics_test.cc \
+			      unittests/table_identifier.cc \
+			      unittests/temporal_format_test.cc \
+			      unittests/temporal_generator.cc  \
+			      unittests/timestamp_test.cc \
+			      unittests/time_test.cc \
+			      unittests/utf8_test.cc
 
 unittests_unittests_LDADD= \
   $(filter-out drizzled/main.$(OBJEXT), ${am_drizzled_drizzled_OBJECTS}) \
-  ${drizzled_drizzled_LDADD} -lboost_unit_test_framework ${BOOST_LIBS} \
-  libdrizzle/libdrizzle.la
+  ${drizzled_drizzled_LDADD} ${BOOST_LIBS} libdrizzle/libdrizzle.la \
+  ${LTLIBBOOST_UNIT_TEST_FRAMEWORK} ${LTLIBBOOST_UNIT_TEST_FRAMEWORK_MT}

=== added file 'unittests/libdrizzle_test.cc'
--- unittests/libdrizzle_test.cc	1970-01-01 00:00:00 +0000
+++ unittests/libdrizzle_test.cc	2011-01-23 21:32:31 +0000
@@ -0,0 +1,63 @@
+/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Andrew Hutchings
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#define BOOST_TEST_DYN_LINK
+#include <boost/test/unit_test.hpp>
+
+#include <libdrizzle/drizzle_client.h>
+#include <libdrizzle/drizzle_server.h>
+
+BOOST_AUTO_TEST_SUITE(LibDrizzle)
+BOOST_AUTO_TEST_CASE(drizzleEscapeString)
+{
+  const char* orig= "hello \"world\"\n";
+  char out[255];
+  size_t out_len;
+
+  out_len= drizzle_escape_string(out, orig, strlen(orig));
+
+  BOOST_REQUIRE_EQUAL(17, out_len);
+  BOOST_REQUIRE_EQUAL("hello \\\"world\\\"\\n", out);
+}
+
+BOOST_AUTO_TEST_CASE(drizzleHexString)
+{
+  const unsigned char orig[5]= {0x34, 0x26, 0x80, 0x99, 0xFF};
+  char out[255];
+  size_t out_len;
+
+  out_len= drizzle_hex_string(out, (char*) orig, 5);
+
+  BOOST_REQUIRE_EQUAL(10, out_len);
+  BOOST_REQUIRE_EQUAL("34268099FF", out);
+}
+
+BOOST_AUTO_TEST_CASE(drizzleMysqlPasswordHash)
+{
+  const char* orig= "test password";
+  char out[255];
+
+  drizzle_mysql_password_hash(out, orig, strlen(orig));
+
+  BOOST_REQUIRE_EQUAL("3B942720DACACBBA7E3838AF03C5B6B5A6DFE0AB", out);
+}
+BOOST_AUTO_TEST_SUITE_END()

=== modified file 'unittests/main.cc'
--- unittests/main.cc	2011-01-20 17:22:18 +0000
+++ unittests/main.cc	2011-01-23 21:32:31 +0000
@@ -1,6 +1,41 @@
+/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 Andrew Hutchings
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
 #define BOOST_TEST_DYN_LINK
 #define BOOST_TEST_MAIN
 #include <boost/test/unit_test.hpp>
+#include <iostream>
+
+struct MyConfig
+{
+    MyConfig()
+    {
+       boost::unit_test::unit_test_log.set_threshold_level(boost::unit_test::log_messages);
+    }
+
+    ~MyConfig()
+    {
+    }
+};
+
+BOOST_GLOBAL_FIXTURE( MyConfig )
 
 BOOST_AUTO_TEST_CASE(MainInit)
 {

=== added file 'unittests/micro_timestamp_test.cc'
--- unittests/micro_timestamp_test.cc	1970-01-01 00:00:00 +0000
+++ unittests/micro_timestamp_test.cc	2011-01-23 21:32:31 +0000
@@ -0,0 +1,112 @@
+/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Pawel Blokus
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#define BOOST_TEST_DYN_LINK
+#include <boost/test/unit_test.hpp>
+
+#include <drizzled/temporal.h>
+
+#include "temporal_generator.h"
+
+using namespace drizzled;
+
+class MicroTimestampTest
+{
+  protected:
+    MicroTimestamp micro_timestamp;
+    bool result;
+};
+
+BOOST_FIXTURE_TEST_SUITE(MicroTimestampTestSuite, MicroTimestampTest)
+BOOST_AUTO_TEST_CASE(is_valid_minOfMicroTimestampRange_shouldReturn_True)
+{
+  uint32_t year= 1970, month= 1, day= 1, hour= 0, minute= 0, second= 0, microsecond= 0;
+  TemporalGenerator::TimestampGen::make_micro_timestamp(&micro_timestamp, year, month, day, hour, minute, second, microsecond);
+
+  result= micro_timestamp.is_valid();
+
+  BOOST_REQUIRE(result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_maxOfMicroTimestampRange_shouldReturn_True)
+{
+  uint32_t year= 2038, month= 1, day= 19, hour= 3, minute= 14, second= 7, microsecond= 0;
+  TemporalGenerator::TimestampGen::make_micro_timestamp(&micro_timestamp, year, month, day, hour, minute, second, microsecond);
+
+  result= micro_timestamp.is_valid();
+
+  BOOST_REQUIRE(result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_oneMicroSecondBeforeMicroTimestampMinOfRange_shouldReturn_False)
+{
+  uint32_t year= 1969, month= 12, day= 31, hour= 23, minute= 59, second= 59, microsecond= 999999;
+  TemporalGenerator::TimestampGen::make_micro_timestamp(&micro_timestamp, year, month, day, hour, minute, second, microsecond);
+
+  result= micro_timestamp.is_valid();
+
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_oneMicroSecondAfterMicroTimestampMaxOfRange_shouldReturn_False)
+{
+  uint32_t year= 2038, month= 1, day= 19, hour= 3, minute= 14, second= 8, microsecond= 1;
+  TemporalGenerator::TimestampGen::make_micro_timestamp(&micro_timestamp, year, month, day, hour, minute, second, microsecond);
+
+  result= micro_timestamp.is_valid();
+
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_InsideOfMicroTimestampRange_shouldReturn_True)
+{
+  uint32_t year= 1980, month= 11, day= 1, hour= 5, minute= 8, second= 5, microsecond= 18263;
+  TemporalGenerator::TimestampGen::make_micro_timestamp(&micro_timestamp, year, month, day, hour, minute, second, microsecond);
+
+  result= micro_timestamp.is_valid();
+
+  BOOST_REQUIRE(result);
+}
+
+BOOST_AUTO_TEST_CASE(to_string_shouldProduce_hyphenSeperatedDateElements_and_colonSeperatedTimeElements)
+{
+  char expected[MicroTimestamp::MAX_STRING_LENGTH]= "2010-05-01 08:07:06.007654";
+  char returned[MicroTimestamp::MAX_STRING_LENGTH];
+  TemporalGenerator::TimestampGen::make_micro_timestamp(&micro_timestamp, 2010, 5, 1, 8, 7, 6, 7654);
+  
+  micro_timestamp.to_string(returned, MicroTimestamp::MAX_STRING_LENGTH);
+  
+  BOOST_REQUIRE_EQUAL(expected, returned);
+}
+
+BOOST_AUTO_TEST_CASE(to_timeval)
+{
+  struct timeval filled;
+  uint32_t year= 2009, month= 6, day= 3, hour= 4, minute= 59, second= 1, microsecond= 675;
+  TemporalGenerator::TimestampGen::make_micro_timestamp(&micro_timestamp, year, month, day, hour, minute, second, microsecond);
+
+  micro_timestamp.to_timeval(filled);
+
+  BOOST_REQUIRE_EQUAL(1244005141, filled.tv_sec);
+  BOOST_REQUIRE_EQUAL(675, filled.tv_usec);
+}
+BOOST_AUTO_TEST_SUITE_END()

=== added file 'unittests/nano_timestamp_test.cc'
--- unittests/nano_timestamp_test.cc	1970-01-01 00:00:00 +0000
+++ unittests/nano_timestamp_test.cc	2011-01-23 21:32:31 +0000
@@ -0,0 +1,101 @@
+/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Pawel Blokus
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#define BOOST_TEST_DYN_LINK
+#include <boost/test/unit_test.hpp>
+
+#include <drizzled/temporal.h>
+
+#include "temporal_generator.h"
+
+using namespace drizzled;
+
+class NanoTimestampTest
+{
+  protected:
+    NanoTimestamp nano_timestamp;
+    bool result;
+};
+
+BOOST_FIXTURE_TEST_SUITE(NanoTimestampTestSuite, NanoTimestampTest)
+BOOST_AUTO_TEST_CASE(is_valid_minOfNanoTimestampRange_shouldReturn_True)
+{
+  uint32_t year= 1970, month= 1, day= 1, hour= 0, minute= 0, second= 0, nanosecond= 0;
+  TemporalGenerator::TimestampGen::make_nano_timestamp(&nano_timestamp, year, month, day, hour, minute, second, nanosecond);
+
+  result= nano_timestamp.is_valid();
+
+  BOOST_REQUIRE(result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_maxOfNanoTimestampRange_shouldReturn_True)
+{
+  uint32_t year= 2038, month= 1, day= 19, hour= 3, minute= 14, second= 7, nanosecond= 0;
+  TemporalGenerator::TimestampGen::make_nano_timestamp(&nano_timestamp, year, month, day, hour, minute, second, nanosecond);
+
+  result= nano_timestamp.is_valid();
+
+  BOOST_REQUIRE(result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_oneMicroSecondBeforeNanoTimestampMinOfRange_shouldReturn_False)
+{
+  uint32_t year= 1969, month= 12, day= 31, hour= 23, minute= 59, second= 59, nanosecond= 999999999;
+  TemporalGenerator::TimestampGen::make_nano_timestamp(&nano_timestamp, year, month, day, hour, minute, second, nanosecond);
+
+  result= nano_timestamp.is_valid();
+
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_oneMicroSecondAfterNanoTimestampMaxOfRange_shouldReturn_False)
+{
+  uint32_t year= 2038, month= 1, day= 19, hour= 3, minute= 14, second= 8, nanosecond= 1;
+  TemporalGenerator::TimestampGen::make_nano_timestamp(&nano_timestamp, year, month, day, hour, minute, second, nanosecond);
+
+  result= nano_timestamp.is_valid();
+
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_InsideOfNanoTimestampRange_shouldReturn_True)
+{
+  uint32_t year= 1980, month= 11, day= 1, hour= 5, minute= 8, second= 5, nanosecond= 3265832;
+  TemporalGenerator::TimestampGen::make_nano_timestamp(&nano_timestamp, year, month, day, hour, minute, second, nanosecond);
+
+  result= nano_timestamp.is_valid();
+
+  BOOST_REQUIRE(result);
+}
+
+BOOST_AUTO_TEST_CASE(to_timespec)
+{
+  struct timespec filled;
+  uint32_t year= 2009, month= 6, day= 3, hour= 4, minute= 59, second= 1, nanosecond= 675;
+  TemporalGenerator::TimestampGen::make_nano_timestamp(&nano_timestamp, year, month, day, hour, minute, second, nanosecond);
+
+  nano_timestamp.to_timespec(&filled);
+
+  BOOST_REQUIRE_EQUAL(1244005141, filled.tv_sec);
+  BOOST_REQUIRE_EQUAL(675, filled.tv_nsec);
+}
+BOOST_AUTO_TEST_SUITE_END()

=== added file 'unittests/option_context.cc'
--- unittests/option_context.cc	1970-01-01 00:00:00 +0000
+++ unittests/option_context.cc	2011-01-23 21:32:31 +0000
@@ -0,0 +1,60 @@
+/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Monty Taylor
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#define BOOST_TEST_DYN_LINK
+#include <boost/test/unit_test.hpp>
+
+#include <boost/program_options.hpp>
+
+#include "drizzled/module/option_context.h"
+
+namespace po=boost::program_options;
+
+using namespace drizzled;
+
+BOOST_AUTO_TEST_SUITE(OptionContext)
+BOOST_AUTO_TEST_CASE(parsing)
+{
+  const std::string module_name("test");
+  po::options_description command_line_options("Test prefix injection");
+  module::option_context ctx(module_name, command_line_options.add_options());
+
+  ctx("option", po::value<std::string>(), "Test option name prefix injection");
+
+  po::variables_map vm;
+
+  const char *options[]= {
+    "test", "--test.option=foo"
+  };
+
+  // Disable allow_guessing
+  int style = po::command_line_style::default_style & ~po::command_line_style::allow_guessing;
+
+  po::store(po::command_line_parser(2, (char **)options).style(style).
+            options(command_line_options).run(), vm);
+  po::notify(vm);
+
+  BOOST_REQUIRE_EQUAL(0, vm.count("option"));
+  BOOST_REQUIRE_EQUAL(1, vm.count("test.option"));
+  BOOST_REQUIRE_EQUAL(0, vm["test.option"].as<std::string>().compare("foo"));
+}
+BOOST_AUTO_TEST_SUITE_END()

=== added file 'unittests/pthread_atomics_test.cc'
--- unittests/pthread_atomics_test.cc	1970-01-01 00:00:00 +0000
+++ unittests/pthread_atomics_test.cc	2011-01-23 21:32:31 +0000
@@ -0,0 +1,130 @@
+/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Stewart Smith
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#define BOOST_TEST_DYN_LINK
+#include <boost/test/unit_test.hpp>
+
+# if defined(__SUNPRO_CC)
+#  include <drizzled/atomic/sun_studio.h>
+# endif
+
+# if !defined(__ICC) && (defined(HAVE_GCC_ATOMIC_BUILTINS) || defined(__SUNPRO_CC))
+#  include <drizzled/atomic/gcc_traits.h>
+#  define ATOMIC_TRAITS internal::gcc_traits
+# else  /* use pthread impl */
+#  define ATOMIC_TRAITS internal::pthread_traits
+# endif
+
+#include <pthread.h>
+#include <drizzled/atomic/pthread_traits.h>
+
+#include <drizzled/atomics.h>
+
+using namespace drizzled;
+
+template<typename T>
+struct atomic_pthread {
+};
+
+#   define __DRIZZLE_DECL_ATOMIC_PTHREAD(T)                              \
+  template<> struct atomic_pthread<T>                                   \
+  : internal::atomic_impl<T,T, internal::pthread_traits<T,T> > {         \
+    atomic_pthread<T>()                                                 \
+      : internal::atomic_impl<T,T, internal::pthread_traits<T,T> >() {}  \
+    T operator=( T rhs ) { return store_with_release(rhs); }            \
+  };
+
+__DRIZZLE_DECL_ATOMIC_PTHREAD(unsigned int)
+
+BOOST_AUTO_TEST_SUITE(PthreadAtomicOperations)
+BOOST_AUTO_TEST_CASE(fetch_and_store)
+{
+  atomic_pthread<uint32_t> u235;
+
+  BOOST_REQUIRE_EQUAL(0, u235.fetch_and_store(1));
+
+  u235.fetch_and_store(15);
+
+  BOOST_REQUIRE_EQUAL(15, u235.fetch_and_store(100));
+  BOOST_REQUIRE_EQUAL(100, u235);
+}
+
+BOOST_AUTO_TEST_CASE(fetch_and_increment)
+{
+  atomic_pthread<uint32_t> u235;
+
+  BOOST_REQUIRE_EQUAL(0, u235.fetch_and_increment());
+  BOOST_REQUIRE_EQUAL(1, u235);
+}
+
+BOOST_AUTO_TEST_CASE(fetch_and_add)
+{
+  atomic_pthread<uint32_t> u235;
+
+  BOOST_REQUIRE_EQUAL(0, u235.fetch_and_add(2));
+  BOOST_REQUIRE_EQUAL(2, u235);
+}
+
+BOOST_AUTO_TEST_CASE(add_and_fetch)
+{
+  atomic_pthread<uint32_t> u235;
+
+  BOOST_REQUIRE_EQUAL(10, u235.add_and_fetch(10));
+  BOOST_REQUIRE_EQUAL(10, u235);
+}
+
+BOOST_AUTO_TEST_CASE(fetch_and_decrement)
+{
+  atomic_pthread<uint32_t> u235;
+
+  u235.fetch_and_store(15);
+
+  BOOST_REQUIRE_EQUAL(15, u235.fetch_and_decrement());
+  BOOST_REQUIRE_EQUAL(14, u235);
+}
+
+BOOST_AUTO_TEST_CASE(compare_and_swap)
+{
+  atomic_pthread<uint32_t> u235;
+
+  u235.fetch_and_store(100);
+
+  BOOST_REQUIRE(not u235.compare_and_swap(42, 200));
+  BOOST_REQUIRE(u235.compare_and_swap(200, 100));
+  BOOST_REQUIRE_EQUAL(200, u235);
+}
+
+BOOST_AUTO_TEST_CASE(increment)
+{
+  atomic_pthread<uint32_t> u235;
+  u235.fetch_and_store(200);
+  BOOST_REQUIRE_EQUAL(201, u235.increment());
+}
+
+BOOST_AUTO_TEST_CASE(decrement)
+{
+  atomic_pthread<uint32_t> u235;
+  u235.fetch_and_store(200);
+
+  BOOST_REQUIRE_EQUAL(199, u235.decrement());
+}
+BOOST_AUTO_TEST_SUITE_END()

=== added file 'unittests/table_identifier.cc'
--- unittests/table_identifier.cc	1970-01-01 00:00:00 +0000
+++ unittests/table_identifier.cc	2011-01-23 21:32:31 +0000
@@ -0,0 +1,91 @@
+/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#define BOOST_TEST_DYN_LINK
+#include <boost/test/unit_test.hpp>
+
+#include <drizzled/identifier.h>
+
+using namespace drizzled;
+
+BOOST_AUTO_TEST_SUITE(TableIdentifierTest)
+BOOST_AUTO_TEST_CASE(CreateStandard)
+{
+  identifier::Table identifier("test", "a");
+  BOOST_REQUIRE_EQUAL("test/a", identifier.getPath());
+  std::string path;
+  identifier.getSQLPath(path);
+  BOOST_REQUIRE_EQUAL("test.a", path);
+}
+
+BOOST_AUTO_TEST_CASE(CreateTemporary)
+{
+  identifier::Table identifier("test", "a", message::Table::TEMPORARY);
+  BOOST_REQUIRE_EQUAL("/#sql", identifier.getPath().substr(0, 5));
+  std::string path;
+  identifier.getSQLPath(path);
+  BOOST_REQUIRE_EQUAL("test.#a", path);
+}
+
+BOOST_AUTO_TEST_CASE(CreateInternal)
+{
+  identifier::Table identifier("test", "a", message::Table::TEMPORARY);
+  BOOST_REQUIRE_EQUAL("/#sql", identifier.getPath().substr(0, 5));
+  std::string path;
+  identifier.getSQLPath(path);
+  BOOST_REQUIRE_EQUAL("test.#a", path);
+}
+
+BOOST_AUTO_TEST_CASE(StaticTmpTable)
+{
+  std::vector<char> pathname;
+
+  identifier::Table::build_tmptable_filename(pathname);
+
+  BOOST_REQUIRE_GT(pathname.size(), 0);
+  BOOST_REQUIRE_GT(strlen(&pathname[0]), 0);
+}
+
+BOOST_AUTO_TEST_CASE(Key)
+{
+  identifier::Table identifier("test", "a");
+
+  const identifier::Table::Key key= identifier.getKey();
+
+  BOOST_REQUIRE_EQUAL(key.size(), 7);
+  BOOST_REQUIRE_EQUAL(key.vector()[0], 't');
+  BOOST_REQUIRE_EQUAL(key.vector()[1], 'e');
+  BOOST_REQUIRE_EQUAL(key.vector()[2], 's');
+  BOOST_REQUIRE_EQUAL(key.vector()[3], 't');
+  BOOST_REQUIRE_EQUAL(key.vector()[4], 0);
+  BOOST_REQUIRE_EQUAL(key.vector()[5], 'a');
+  BOOST_REQUIRE_EQUAL(key.vector()[6], 0);
+}
+
+BOOST_AUTO_TEST_CASE(KeyCompare)
+{
+  identifier::Table identifier("test", "a");
+  identifier::Table identifier2("test", "a");
+
+  BOOST_REQUIRE_EQUAL((identifier.getKey() == identifier.getKey()), true);
+}
+BOOST_AUTO_TEST_SUITE_END()

=== added file 'unittests/temporal_format_test.cc'
--- unittests/temporal_format_test.cc	1970-01-01 00:00:00 +0000
+++ unittests/temporal_format_test.cc	2011-01-23 21:32:31 +0000
@@ -0,0 +1,157 @@
+/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Pawel Blokus
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#include <drizzled/temporal.h>
+#include <drizzled/temporal_format.h>
+
+#define BOOST_TEST_DYN_LINK
+#include <boost/test/unit_test.hpp>
+
+#include <vector>
+
+#include "temporal_generator.h"
+
+using namespace drizzled;
+
+class TemporalFormatTest
+{
+  protected:
+    TemporalFormat *tf;
+    Temporal *temporal;
+    bool result;
+
+  TemporalFormatTest()
+  {
+    tf= NULL;
+    temporal= NULL;
+  }
+
+  ~TemporalFormatTest()
+  {
+    if (tf != NULL)
+      delete tf;
+    if (temporal != NULL)
+      delete temporal;
+  }
+};
+
+BOOST_FIXTURE_TEST_SUITE(TemporalFormatTestSuite, TemporalFormatTest)
+BOOST_AUTO_TEST_CASE(constructor_WithValidRegExp_shouldCompile)
+{
+  tf= new TemporalFormat("^(\\d{4})[-/.]$");
+  
+  result= tf->is_valid();
+
+  BOOST_REQUIRE(result);
+}
+
+BOOST_AUTO_TEST_CASE(constructor_WithInvalidRegExp_shouldNotCompile)
+{
+  tf= new TemporalFormat("^\\d{4)[-/.]$");
+
+  result= tf->is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(matches_OnNotMatchingString_shouldReturn_False)
+{
+  tf= new TemporalFormat("^(\\d{4})[-/.]$");
+  char matched[] ="1234/ABC";
+
+  result= tf->matches(matched, sizeof(matched) - sizeof(char), NULL);
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(matches_OnMatchingString_FormatWithIndexesSet_shouldPopulateTemporal)
+{
+  char regexp[]= "^(\\d{4})[-/.](\\d{1,2})[-/.](\\d{1,2})[T|\\s+](\\d{2}):(\\d{2}):(\\d{2})$";
+  char matched[]= "1999/9/14T23:29:05";
+  tf= TemporalGenerator::TemporalFormatGen::make_temporal_format(regexp, 1, 2, 3, 4, 5, 6, 0, 0);
+  temporal= new DateTime();
+
+  
+  result= tf->matches(matched, sizeof(matched) - sizeof(char), temporal);
+  BOOST_REQUIRE(result);
+  
+  BOOST_REQUIRE_EQUAL(1999, temporal->years());
+  BOOST_REQUIRE_EQUAL(9, temporal->months());
+  BOOST_REQUIRE_EQUAL(14, temporal->days());
+  BOOST_REQUIRE_EQUAL(23, temporal->hours());
+  BOOST_REQUIRE_EQUAL(29, temporal->minutes());
+  BOOST_REQUIRE_EQUAL(5, temporal->seconds());
+}
+
+BOOST_AUTO_TEST_CASE(matches_FormatWithMicroSecondIndexSet_shouldAddTrailingZeros)
+{
+  tf= TemporalGenerator::TemporalFormatGen::make_temporal_format("^(\\d{1,6})$", 0, 0, 0, 0, 0, 0, 1, 0);
+  char matched[]= "560";
+  temporal= new Time();
+  
+  tf->matches(matched, sizeof(matched) - sizeof(char), temporal);
+  
+  BOOST_REQUIRE_EQUAL(560000, temporal->useconds());
+}
+
+BOOST_AUTO_TEST_CASE(matches_FormatWithNanoSecondIndexSet_shouldAddTrailingZeros)
+{
+  tf= TemporalGenerator::TemporalFormatGen::make_temporal_format("^(\\d{1,9})$", 0, 0, 0, 0, 0, 0, 0, 1);
+  char matched[]= "4321";
+  temporal= new Time();
+  
+  tf->matches(matched, sizeof(matched) - sizeof(char), temporal);
+  
+  BOOST_REQUIRE_EQUAL(432100000, temporal->nseconds());
+}
+BOOST_AUTO_TEST_SUITE_END()
+
+namespace drizzled
+{
+extern std::vector<TemporalFormat *> known_datetime_formats;
+extern std::vector<TemporalFormat *> known_date_formats;
+extern std::vector<TemporalFormat *> known_time_formats;
+extern std::vector<TemporalFormat *> all_temporal_formats;
+}
+
+BOOST_AUTO_TEST_SUITE(TemporalFormatTestSuite)
+BOOST_AUTO_TEST_CASE(init_temporal_formats_vectorsWithKnownFormats_shouldHaveExpectedLengths)
+{
+  init_temporal_formats();
+
+  BOOST_REQUIRE_EQUAL(13, known_datetime_formats.size());	
+  BOOST_REQUIRE_EQUAL(8, known_date_formats.size());
+  BOOST_REQUIRE_EQUAL(11, known_time_formats.size());
+  BOOST_REQUIRE_EQUAL(19, all_temporal_formats.size());
+}
+
+BOOST_AUTO_TEST_CASE(deinit_temporal_formats_vectorsWithKnownFormats_shouldHaveZeroLengths)
+{
+  init_temporal_formats();
+  deinit_temporal_formats();
+  
+  BOOST_REQUIRE_EQUAL(0, known_datetime_formats.size());
+  BOOST_REQUIRE_EQUAL(0, known_date_formats.size());
+  BOOST_REQUIRE_EQUAL(0, known_time_formats.size());
+  BOOST_REQUIRE_EQUAL(0, all_temporal_formats.size());
+}
+BOOST_AUTO_TEST_SUITE_END()

=== added file 'unittests/temporal_generator.cc'
--- unittests/temporal_generator.cc	1970-01-01 00:00:00 +0000
+++ unittests/temporal_generator.cc	2011-01-23 21:32:31 +0000
@@ -0,0 +1,195 @@
+/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Pawel Blokus
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#include <drizzled/temporal.h>
+#include <drizzled/temporal_format.h>
+#include <drizzled/temporal_interval.h>
+
+#include "temporal_generator.h"
+
+using namespace drizzled;
+
+void TemporalGenerator::DateGen::make_date(Date *date,
+                                          uint32_t years, uint32_t months, uint32_t days)
+{
+  date->set_years(years);
+  date->set_months(months);
+  date->set_days(days);
+  date->set_epoch_seconds();
+}
+
+void TemporalGenerator::DateGen::make_valid_date(drizzled::Date *date)
+{
+  date->set_years(2005);
+  date->set_months(5);
+  date->set_days(26);
+  date->set_epoch_seconds();
+}
+
+void TemporalGenerator::TemporalGen::leap_day_in_leap_year(drizzled::Temporal *temporal)
+{
+  temporal->set_years(2008);
+  temporal->set_months(2);
+  temporal->set_days(29);
+  temporal->set_epoch_seconds();
+}
+
+void TemporalGenerator::TemporalGen::leap_day_in_non_leap_year(drizzled::Temporal *temporal)
+{
+  temporal->set_years(2010);
+  temporal->set_months(2);
+  temporal->set_days(29);
+  temporal->set_epoch_seconds();
+}
+
+void TemporalGenerator::TimeGen::make_time(drizzled::Time *time,
+                                   uint32_t hours, uint32_t minutes, uint32_t seconds,
+                                   uint32_t useconds)
+{
+  time->set_hours(hours);
+  time->set_minutes(minutes);
+  time->set_seconds(seconds);
+  time->set_useconds(useconds);
+  time->set_epoch_seconds();
+}
+
+void TemporalGenerator::TemporalGen::make_min_time(drizzled::Temporal *temporal)
+{
+  temporal->set_hours(0);
+  temporal->set_minutes(0);
+  temporal->set_seconds(0);
+  temporal->set_epoch_seconds();
+}
+
+void TemporalGenerator::TemporalGen::make_max_time(drizzled::Temporal *temporal)
+{
+  temporal->set_hours(23);
+  temporal->set_minutes(59);
+  temporal->set_seconds(59);
+  temporal->set_epoch_seconds();
+}
+
+void TemporalGenerator::DateTimeGen::make_datetime(drizzled::DateTime *datetime,
+                   uint32_t years, uint32_t months, uint32_t days, uint32_t hours,
+                   uint32_t minutes, uint32_t seconds, uint32_t useconds)
+{
+  datetime->set_years(years);
+  datetime->set_months(months);
+  datetime->set_days(days);
+  datetime->set_hours(hours);
+  datetime->set_minutes(minutes);
+  datetime->set_seconds(seconds);
+  datetime->set_useconds(useconds);
+  datetime->set_epoch_seconds();
+}                     
+
+void TemporalGenerator::DateTimeGen::make_valid_datetime(drizzled::DateTime *datetime)
+{
+  datetime->set_years(1999);
+  datetime->set_months(8);
+  datetime->set_days(15);
+  datetime->set_hours(13);
+  datetime->set_minutes(34);
+  datetime->set_seconds(6);
+  datetime->set_epoch_seconds();
+}
+
+void TemporalGenerator::TimestampGen::make_timestamp(drizzled::Timestamp *timestamp,
+                                             uint32_t years, uint32_t months, uint32_t days,
+                                             uint32_t hours, uint32_t minutes, uint32_t seconds)
+{
+  timestamp->set_years(years);
+  timestamp->set_months(months);
+  timestamp->set_days(days);
+  timestamp->set_hours(hours);
+  timestamp->set_minutes(minutes);
+  timestamp->set_seconds(seconds);
+  timestamp->set_epoch_seconds();
+}
+
+void TemporalGenerator::TimestampGen::make_micro_timestamp(drizzled::MicroTimestamp *timestamp,
+                                                   uint32_t years, uint32_t months, uint32_t days,
+                                                   uint32_t hours, uint32_t minutes,
+                                                   uint32_t seconds, uint32_t microseconds)
+{
+  make_timestamp(timestamp, years, months, days, hours, minutes, seconds);
+  timestamp->set_useconds(microseconds);
+  timestamp->set_epoch_seconds();
+}
+                                 
+void TemporalGenerator::TimestampGen::make_nano_timestamp(drizzled::NanoTimestamp *timestamp,
+                                                  uint32_t years, uint32_t months, uint32_t days,
+                                                  uint32_t hours, uint32_t minutes,
+                                                  uint32_t seconds, uint32_t nanoseconds)
+{
+  make_timestamp(timestamp, years, months, days, hours, minutes, seconds);
+  timestamp->set_nseconds(nanoseconds);
+  timestamp->set_epoch_seconds();
+}
+
+drizzled::TemporalFormat *TemporalGenerator::TemporalFormatGen::make_temporal_format(const char *regexp,
+                                                                  int32_t year_part_index,
+                                                                  int32_t month_part_index,
+                                                                  int32_t day_part_index,
+                                                                  int32_t hour_part_index,
+                                                                  int32_t minute_part_index,
+                                                                  int32_t second_part_index,
+                                                                  int32_t usecond_part_index,
+                                                                  int32_t nsecond_part_index)
+{
+  drizzled::TemporalFormat *temporal_format= new drizzled::TemporalFormat(regexp);
+
+  temporal_format->set_year_part_index(year_part_index);
+  temporal_format->set_month_part_index(month_part_index);
+  temporal_format->set_day_part_index(day_part_index);
+  temporal_format->set_hour_part_index(hour_part_index);
+  temporal_format->set_minute_part_index(minute_part_index);
+  temporal_format->set_second_part_index(second_part_index);
+  temporal_format->set_usecond_part_index(usecond_part_index);
+  temporal_format->set_nsecond_part_index(nsecond_part_index);
+
+  return temporal_format;
+}
+
+drizzled::TemporalInterval *TemporalGenerator::TemporalIntervalGen::make_temporal_interval(
+                                                                                           uint32_t  year,
+                                                                                           uint32_t  month,
+                                                                                           uint32_t  day,
+                                                                                           uint32_t  hour,
+                                                                                           uint64_t  minute,
+                                                                                           uint64_t  second,
+                                                                                           uint64_t  second_part,
+                                                                                           bool neg)
+{
+  drizzled::TemporalInterval *interval= new drizzled::TemporalInterval();
+
+  interval->set_year(year);
+  interval->set_month(month);
+  interval->set_day(day);
+  interval->set_hour(hour);
+  interval->set_minute(minute);
+  interval->set_second(second);
+  interval->set_second_part(second_part);
+  interval->setNegative(neg);
+
+  return interval;
+}

=== added file 'unittests/time_test.cc'
--- unittests/time_test.cc	1970-01-01 00:00:00 +0000
+++ unittests/time_test.cc	2011-01-23 21:32:31 +0000
@@ -0,0 +1,385 @@
+/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+*  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+*
+*  Copyright (C) 2010 Pawel Blokus
+*
+*  This program is free software; you can redistribute it and/or modify
+*  it under the terms of the GNU General Public License as published by
+*  the Free Software Foundation; either version 2 of the License, or
+*  (at your option) any later version.
+*
+*  This program is distributed in the hope that it will be useful,
+*  but WITHOUT ANY WARRANTY; without even the implied warranty of
+*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+*  GNU General Public License for more details.
+*
+*  You should have received a copy of the GNU General Public License
+*  along with this program; if not, write to the Free Software
+*  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+*/
+
+#include "config.h"
+
+#define BOOST_TEST_DYN_LINK
+#include <boost/test/unit_test.hpp>
+
+#include <drizzled/type/decimal.h>
+#include <drizzled/temporal.h>
+#include <drizzled/temporal_format.h>
+
+#include "temporal_generator.h"
+
+using namespace drizzled;
+
+class TimeTest
+{
+protected:
+  Time sample_time;
+  bool result;
+  uint32_t hours, minutes, seconds;
+  
+  Time identical_with_sample_time, before_sample_time, after_sample_time;
+  
+  TimeTest()
+  {
+    TemporalGenerator::TimeGen::make_time(&sample_time, 18, 34, 59);
+    
+    TemporalGenerator::TimeGen::make_time(&before_sample_time, 18, 34, 58);
+    TemporalGenerator::TimeGen::make_time(&identical_with_sample_time, 18, 34, 59);
+    TemporalGenerator::TimeGen::make_time(&after_sample_time, 18, 35, 0);
+    
+  }
+
+  void assign_time_values()
+  {
+    hours= sample_time.hours();
+    minutes= sample_time.minutes();
+    seconds= sample_time.seconds();
+  }
+
+  void from_string(const char *string)
+  {
+    
+    init_temporal_formats();
+    result= sample_time.from_string(string, strlen(string));
+    deinit_temporal_formats();
+    
+    assign_time_values();
+  }
+};
+
+BOOST_FIXTURE_TEST_SUITE(TimeTestSuite, TimeTest)
+BOOST_AUTO_TEST_CASE(operatorEqual_ComparingWithIdencticalTime_ShouldReturn_True)
+{
+  this->result= (this->sample_time == this->identical_with_sample_time);
+  
+  BOOST_REQUIRE(this->result);
+}
+
+BOOST_AUTO_TEST_CASE(operatorEqual_ComparingWithDifferentTemporal_ShouldReturn_False)
+{
+  this->result= (this->sample_time == this->before_sample_time);
+  
+  BOOST_REQUIRE(not this->result);
+}
+
+BOOST_AUTO_TEST_CASE(operatorNotEqual_ComparingWithIdencticalTemporal_ShouldReturn_False)
+{ 
+  this->result= (this->sample_time != this->identical_with_sample_time);
+  
+  BOOST_REQUIRE(not this->result);
+}
+
+BOOST_AUTO_TEST_CASE(operatorNotEqual_ComparingWithDifferentTemporal_ShouldReturn_True)
+{
+  this->result= (this->sample_time != this->before_sample_time);
+  
+  BOOST_REQUIRE(this->result);
+}
+
+BOOST_AUTO_TEST_CASE(operatorGreaterThan_ComparingWithIdenticalTemporal_ShouldReturn_False)
+{
+  this->result= (this->sample_time > this->identical_with_sample_time);
+  
+  BOOST_REQUIRE(not this->result);
+}
+
+BOOST_AUTO_TEST_CASE(operatorGreaterThan_ComparingWithLaterTemporal_ShouldReturn_False)
+{
+  this->result= (this->sample_time > this->after_sample_time);
+  
+  BOOST_REQUIRE(not this->result);
+}
+
+BOOST_AUTO_TEST_CASE(operatorGreaterThan_ComparingWithEarlierTemporal_ShouldReturn_True)
+{
+  this->result= (this->sample_time > this->before_sample_time);
+  
+  BOOST_REQUIRE(this->result);
+}
+
+BOOST_AUTO_TEST_CASE(operatorGreaterThanOrEqual_ComparingWithIdenticalTemporal_ShouldReturn_True)
+{
+  this->result= (this->sample_time >= this->identical_with_sample_time);
+  
+  BOOST_REQUIRE(this->result);
+}
+
+BOOST_AUTO_TEST_CASE(operatorGreaterThanOrEqual_ComparingWithLaterTemporal_ShouldReturn_False)
+{
+  this->result= (this->sample_time >= this->after_sample_time);
+  
+  BOOST_REQUIRE(not this->result);
+}
+
+BOOST_AUTO_TEST_CASE(operatorGreaterThanOrEqual_ComparingWithEarlierTemporal_ShouldReturn_True)
+{
+  this->result= (this->sample_time >= this->before_sample_time);
+  
+  BOOST_REQUIRE(this->result);
+}
+
+BOOST_AUTO_TEST_CASE(operatorLessThan_ComparingWithIdenticalTemporal_ShouldReturn_False)
+{
+  this->result= (this->sample_time < this->identical_with_sample_time);
+  
+  BOOST_REQUIRE(not this->result);
+}
+
+BOOST_AUTO_TEST_CASE(operatorLessThan_ComparingWithLaterTemporal_ShouldReturn_True)
+{
+  this->result= (this->sample_time < this->after_sample_time);
+  
+  BOOST_REQUIRE(this->result);
+}
+
+BOOST_AUTO_TEST_CASE(operatorLessThan_ComparingWithEarlierTemporal_ShouldReturn_False)
+{
+  this->result= (this->sample_time < this->before_sample_time);
+  
+  BOOST_REQUIRE(not this->result);
+}
+
+BOOST_AUTO_TEST_CASE(operatorLessThanOrEqual_ComparingWithIdenticalTemporal_ShouldReturn_True)
+{
+  this->result= (this->sample_time <= this->identical_with_sample_time);
+  
+  BOOST_REQUIRE(this->result);
+}
+
+BOOST_AUTO_TEST_CASE(operatorLessThanOrEqual_ComparingWithLaterTemporal_ShouldReturn_True)
+{
+  this->result= (this->sample_time <= this->after_sample_time);
+  
+  BOOST_REQUIRE(this->result);
+}
+
+BOOST_AUTO_TEST_CASE(operatorLessThanOrEqual_ComparingWithEarlierTemporal_ShouldReturn_False)
+{
+  this->result= (this->sample_time <= this->before_sample_time);
+  
+  BOOST_REQUIRE(not this->result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_onValidTime_shouldReturn_True)
+{
+  result= sample_time.is_valid();
+  
+  BOOST_REQUIRE(result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_onValidMinimalTime_shouldReturn_True)
+{
+  TemporalGenerator::TemporalGen::make_min_time(&sample_time);
+  
+  result= sample_time.is_valid();
+  
+  BOOST_REQUIRE(result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_onValidMaximalTime_shouldReturn_True)
+{
+  TemporalGenerator::TemporalGen::make_max_time(&sample_time);
+  
+  result= sample_time.is_valid();
+  
+  BOOST_REQUIRE(result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_onInvalidTimeWithHourAboveMaximum23_shouldReturn_False)
+{
+  sample_time.set_hours(24);
+  
+  result= sample_time.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_onInvalidTimeWithMinutesAboveMaximum59_shouldReturn_False)
+{
+  sample_time.set_minutes(60);
+  
+  result= sample_time.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_onInvalidTimeWithSecondsAboveMaximum59_shouldReturn_False)
+{
+  sample_time.set_seconds(60);
+  
+  result= sample_time.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(to_string_shouldProduce_colonSeperatedTimeElements)
+{
+  char expected[Time::MAX_STRING_LENGTH]= "18:34:59";
+  char returned[Time::MAX_STRING_LENGTH];
+  
+  sample_time.to_string(returned, Time::MAX_STRING_LENGTH);
+  
+  BOOST_REQUIRE_EQUAL(expected, returned);  
+}
+
+BOOST_AUTO_TEST_CASE(to_string_nullBuffer_shouldReturnProperLengthAnyway)
+{
+  int length= sample_time.to_string(NULL, 0);
+  
+  BOOST_REQUIRE_EQUAL(Time::MAX_STRING_LENGTH - 1, length);  
+}
+
+BOOST_AUTO_TEST_CASE(to_int32_t)
+{
+  int32_t representation;
+
+  sample_time.to_int32_t(&representation);
+
+  BOOST_REQUIRE_EQUAL(representation, 183459);
+}
+
+BOOST_AUTO_TEST_CASE(from_int32_t_shouldPopulateTimeCorrectly)
+{
+  sample_time.from_int32_t(183459);
+  
+  assign_time_values();;
+  
+  BOOST_REQUIRE_EQUAL(18, hours);
+  BOOST_REQUIRE_EQUAL(34, minutes);
+  BOOST_REQUIRE_EQUAL(59, seconds);
+}
+
+BOOST_AUTO_TEST_CASE(from_time_t)
+{
+  sample_time.from_time_t(59588);
+  
+  assign_time_values();
+  
+  BOOST_REQUIRE_EQUAL(16, hours);  
+  BOOST_REQUIRE_EQUAL(33, minutes);
+  BOOST_REQUIRE_EQUAL(8, seconds);
+}
+
+BOOST_AUTO_TEST_CASE(to_decimal)
+{
+  drizzled::type::Decimal to;
+  TemporalGenerator::TimeGen::make_time(&sample_time, 8, 4, 9, 56);
+
+  sample_time.to_decimal(&to);
+  
+  BOOST_REQUIRE_EQUAL(80409, to.buf[0]);
+  BOOST_REQUIRE_EQUAL(56000, to.buf[1]);
+}
+
+BOOST_AUTO_TEST_CASE(from_string_invalidString_shouldReturn_False)
+{
+  char invalid_string[Time::MAX_STRING_LENGTH]= "1o:34:59";
+  
+  init_temporal_formats();
+  result= sample_time.from_string(invalid_string, strlen(invalid_string));
+  deinit_temporal_formats();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(from_string_validString_minuteAndSecond_shouldPopulateCorrectly)
+{
+  char valid_string[Time::MAX_STRING_LENGTH]= "4:52";
+
+  from_string(valid_string);
+
+  BOOST_REQUIRE_EQUAL(4, minutes);
+  BOOST_REQUIRE_EQUAL(52, seconds);
+}
+
+BOOST_AUTO_TEST_CASE(from_string_validString_minuteAndSecondNoColon_shouldPopulateCorrectly)
+{
+  char valid_string[Time::MAX_STRING_LENGTH]= "3456";
+  
+  from_string(valid_string);
+  
+  BOOST_REQUIRE_EQUAL(34, minutes);
+  BOOST_REQUIRE_EQUAL(56, seconds);
+}
+
+BOOST_AUTO_TEST_CASE(from_string_validString_secondsOnly_shouldPopulateCorrectly)
+{
+  char valid_string[Time::MAX_STRING_LENGTH]= "59";
+  
+  from_string(valid_string);
+  
+  BOOST_REQUIRE_EQUAL(59, seconds);
+}
+BOOST_AUTO_TEST_SUITE_END()
+
+class TimeFromStringTest
+{
+  protected:
+    Time time;
+    bool result;
+    uint32_t hours, minutes, seconds;
+    
+    TimeFromStringTest()
+    {
+      init_temporal_formats();
+    }
+    
+    ~TimeFromStringTest()
+    {
+      deinit_temporal_formats();
+    }
+    
+    void assign_time_values()
+    {
+      hours= time.hours();
+      minutes= time.minutes();
+      seconds= time.seconds();
+    }
+};
+
+BOOST_FIXTURE_TEST_SUITE(TimeFromStringTestSuite, TimeFromStringTest)
+BOOST_AUTO_TEST_CASE(from_string)
+{
+  const char *valid_strings[]= {"080409",
+                                "80409",
+                                "08:04:09",
+                                "8:04:09",
+                                "8:04:9",
+                                "8:4:9"};
+  for (int it= 0; it < 6; it++)
+  {
+    const char *valid_string= valid_strings[it];
+
+    result= time.from_string(valid_string, strlen(valid_string));
+    BOOST_REQUIRE(result);
+  
+    assign_time_values();
+
+    BOOST_REQUIRE_EQUAL(8, hours);
+    BOOST_REQUIRE_EQUAL(4, minutes);
+    BOOST_REQUIRE_EQUAL(9, seconds);
+  }
+}
+BOOST_AUTO_TEST_SUITE_END()
+                                          

=== added file 'unittests/timestamp_test.cc'
--- unittests/timestamp_test.cc	1970-01-01 00:00:00 +0000
+++ unittests/timestamp_test.cc	2011-01-23 21:32:31 +0000
@@ -0,0 +1,319 @@
+/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Pawel Blokus
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#define BOOST_TEST_DYN_LINK
+#include <boost/test/unit_test.hpp>
+
+#include <drizzled/temporal.h>
+
+#include "temporal_generator.h"
+
+using namespace drizzled;
+
+class DateTimestampTestCompareOperators
+{
+ protected:
+  Timestamp sample_timestamp;
+  bool result;
+  
+  Date identical_with_sample_timestamp, before_sample_timestamp, after_sample_timestamp;
+  
+  DateTimestampTestCompareOperators()
+  {
+    TemporalGenerator::TimestampGen::make_timestamp(&sample_timestamp, 2010, 9, 8, 0, 0, 0);
+    TemporalGenerator::DateGen::make_date(&before_sample_timestamp, 1980, 1, 1);
+    TemporalGenerator::DateGen::make_date(&identical_with_sample_timestamp, 2010, 9, 8);
+    TemporalGenerator::DateGen::make_date(&after_sample_timestamp, 2019, 5, 30);
+  }
+};
+
+class DateTimeTimestampTestCompareOperators
+{
+ protected:
+  Timestamp sample_timestamp;
+  bool result;
+  
+  DateTime identical_with_sample_timestamp, before_sample_timestamp, after_sample_timestamp;
+  
+  DateTimeTimestampTestCompareOperators()
+  {
+    TemporalGenerator::TimestampGen::make_timestamp(&sample_timestamp, 2010, 9, 8, 0, 0, 0);
+    TemporalGenerator::DateTimeGen::make_datetime(&before_sample_timestamp, 1990, 12, 31, 12, 12, 30);
+    TemporalGenerator::DateTimeGen::make_datetime(&identical_with_sample_timestamp, 2010, 9, 8, 0, 0, 0);
+    TemporalGenerator::DateTimeGen::make_datetime(&after_sample_timestamp, 2020, 4, 4, 4, 4, 4);
+  }
+};
+
+class TimestampTimestampTestCompareOperators
+{
+ protected:
+  Timestamp sample_timestamp;
+  bool result;
+  
+  Timestamp identical_with_sample_timestamp, before_sample_timestamp, after_sample_timestamp;
+  
+  TimestampTimestampTestCompareOperators()
+  {
+    TemporalGenerator::TimestampGen::make_timestamp(&sample_timestamp, 2010, 9, 8, 0, 0, 0);
+    TemporalGenerator::TimestampGen::make_timestamp(&before_sample_timestamp, 2010, 9, 7, 23, 59, 59);
+    TemporalGenerator::TimestampGen::make_timestamp(&identical_with_sample_timestamp, 2010, 9, 8, 0, 0, 0);
+    TemporalGenerator::TimestampGen::make_timestamp(&after_sample_timestamp, 2010, 9, 8, 0, 0, 1);
+  }
+};
+
+
+BOOST_AUTO_TEST_SUITE(TimestampCompareTestSuite)
+BOOST_FIXTURE_TEST_CASE(DateTimestampTestCompareTest, DateTimestampTestCompareOperators)
+{
+  this->result= (this->sample_timestamp == this->identical_with_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp == this->before_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp != this->identical_with_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp != this->before_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp > this->identical_with_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp > this->after_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp > this->before_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp >= this->identical_with_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp >= this->after_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp >= this->before_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp < this->identical_with_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp < this->after_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp < this->before_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp <= this->identical_with_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp <= this->after_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp <= this->before_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+}
+
+BOOST_FIXTURE_TEST_CASE(DateTimeTimestampTestCompareTest, DateTimeTimestampTestCompareOperators)
+{
+  this->result= (this->sample_timestamp == this->identical_with_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp == this->before_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp != this->identical_with_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp != this->before_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp > this->identical_with_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp > this->after_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp > this->before_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp >= this->identical_with_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp >= this->after_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp >= this->before_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp < this->identical_with_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp < this->after_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp < this->before_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp <= this->identical_with_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp <= this->after_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp <= this->before_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+}
+
+BOOST_FIXTURE_TEST_CASE(TimestampTimestampTestCompareTest, TimestampTimestampTestCompareOperators)
+{
+  this->result= (this->sample_timestamp == this->identical_with_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp == this->before_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp != this->identical_with_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp != this->before_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp > this->identical_with_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp > this->after_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp > this->before_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp >= this->identical_with_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp >= this->after_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp >= this->before_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp < this->identical_with_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp < this->after_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp < this->before_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+
+  this->result= (this->sample_timestamp <= this->identical_with_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp <= this->after_sample_timestamp);  
+  BOOST_REQUIRE(this->result);
+
+  this->result= (this->sample_timestamp <= this->before_sample_timestamp);  
+  BOOST_REQUIRE(not this->result);
+}
+BOOST_AUTO_TEST_SUITE_END()
+
+class TimestampTest
+{
+  protected:
+    Timestamp timestamp;
+    bool result;
+};
+
+BOOST_FIXTURE_TEST_SUITE(TimestampRangesSuite, TimestampTest)
+BOOST_AUTO_TEST_CASE(is_valid_minOfTimestampRange_shouldReturn_True)
+{
+  uint32_t year= 1970, month= 1, day= 1, hour= 0, minute= 0, second= 0;
+  TemporalGenerator::TimestampGen::make_timestamp(&timestamp, year, month, day, hour, minute, second);
+
+  result= timestamp.is_valid();
+
+  BOOST_REQUIRE(result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_maxOfTimestampRange_shouldReturn_True)
+{
+  uint32_t year= 2038, month= 1, day= 19, hour= 3, minute= 14, second= 7;
+  TemporalGenerator::TimestampGen::make_timestamp(&timestamp, year, month, day, hour, minute, second);
+  
+  result= timestamp.is_valid();
+  
+  BOOST_REQUIRE(result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_oneSecondBeforeTimestampMinOfRange_shouldReturn_False)
+{
+  uint32_t year= 1969, month= 12, day= 31, hour= 23, minute= 59, second= 59;
+  TemporalGenerator::TimestampGen::make_timestamp(&timestamp, year, month, day, hour, minute, second);
+  
+  result= timestamp.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_oneSecondAfterTimestampMaxOfRange_shouldReturn_False)
+{
+  uint32_t year= 2038, month= 1, day= 19, hour= 3, minute= 14, second= 8;
+  TemporalGenerator::TimestampGen::make_timestamp(&timestamp, year, month, day, hour, minute, second);
+  
+  result= timestamp.is_valid();
+  
+  BOOST_REQUIRE(not result);
+}
+
+BOOST_AUTO_TEST_CASE(is_valid_InsideOfTimestampRange_shouldReturn_True)
+{
+  uint32_t year= 1980, month= 11, day= 1, hour= 5, minute= 8, second= 5;
+  TemporalGenerator::TimestampGen::make_timestamp(&timestamp, year, month, day, hour, minute, second);
+  
+  result= timestamp.is_valid();
+  
+  BOOST_REQUIRE(result);
+}
+
+BOOST_AUTO_TEST_CASE(to_time_t)
+{
+  time_t time;
+  TemporalGenerator::TimestampGen::make_timestamp(&timestamp, 2009, 6, 3, 4, 59, 1);
+  
+  timestamp.to_time_t(time);
+  
+  BOOST_REQUIRE_EQUAL(1244005141, time);
+}
+
+BOOST_AUTO_TEST_CASE(outputStreamOperator_shouldWrite_hyphenSeperatedDateElements_and_colonSeperatedTimeElements)
+{
+  std::ostringstream output;
+  std::string expected= "2010-05-01 08:07:06";
+  std::string returned;
+  TemporalGenerator::TimestampGen::make_timestamp(&timestamp, 2010, 5, 1, 8, 7, 6);
+  
+  output << timestamp;
+  returned= output.str();
+  
+  BOOST_REQUIRE_EQUAL(expected, returned);
+}
+BOOST_AUTO_TEST_SUITE_END()

=== added file 'unittests/utf8_test.cc'
--- unittests/utf8_test.cc	1970-01-01 00:00:00 +0000
+++ unittests/utf8_test.cc	2011-01-23 21:32:31 +0000
@@ -0,0 +1,92 @@
+/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Monty Taylor
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#include <string>
+
+#define BOOST_TEST_DYN_LINK
+#include <boost/test/unit_test.hpp>
+
+#include <drizzled/utf8/utf8.h>
+
+using namespace drizzled;
+
+BOOST_AUTO_TEST_SUITE(UTF8)
+BOOST_AUTO_TEST_CASE(is_single)
+{
+  BOOST_REQUIRE(utf8::is_single('a'));
+  const char *multi_byte= "ç";
+  BOOST_REQUIRE(not utf8::is_single(*multi_byte));
+  BOOST_REQUIRE(not utf8::is_single(*(multi_byte + 1)));
+}
+
+BOOST_AUTO_TEST_CASE(codepoint_length)
+{
+  uint32_t one_byte= 0x0024;
+  uint32_t two_bytes= 0x00A2;
+  uint32_t three_bytes= 0x20AC;
+  uint32_t four_bytes= 0x024B62;
+  BOOST_REQUIRE_EQUAL(1, utf8::codepoint_length(one_byte));
+  BOOST_REQUIRE_EQUAL(2, utf8::codepoint_length(two_bytes));
+  BOOST_REQUIRE_EQUAL(3, utf8::codepoint_length(three_bytes));
+  BOOST_REQUIRE_EQUAL(4, utf8::codepoint_length(four_bytes));
+}
+
+BOOST_AUTO_TEST_CASE(sequence_length)
+{
+  const char *one_byte= "$";
+  const char *two_bytes= "¢";
+  const char *three_bytes= "€";
+  const char *four_bytes= "𤭢";
+  BOOST_REQUIRE_EQUAL(1, utf8::sequence_length(*one_byte));
+  BOOST_REQUIRE_EQUAL(2, utf8::sequence_length(*two_bytes));
+  BOOST_REQUIRE_EQUAL(3, utf8::sequence_length(*three_bytes));
+  BOOST_REQUIRE_EQUAL(4, utf8::sequence_length(*four_bytes));
+}
+
+BOOST_AUTO_TEST_CASE(char_length)
+{
+  const char *one_byte= "$";
+  const char *two_bytes= "¢";
+  const char *three_bytes= "€";
+  const char *four_bytes= "𤭢";
+  const char *test_string= "__tañgè Ñãmé";
+  BOOST_REQUIRE_EQUAL(1, utf8::char_length(one_byte));
+  BOOST_REQUIRE_EQUAL(1, utf8::char_length(two_bytes));
+  BOOST_REQUIRE_EQUAL(1, utf8::char_length(three_bytes));
+  BOOST_REQUIRE_EQUAL(1, utf8::char_length(four_bytes));
+  BOOST_REQUIRE_EQUAL(12, utf8::char_length(test_string));
+}
+
+BOOST_AUTO_TEST_CASE(char_length_string)
+{
+  std::string one_byte= "$";
+  std::string two_bytes= "¢";
+  std::string three_bytes= "€";
+  std::string four_bytes= "𤭢";
+  std::string test_string= "__tañgè Ñãmé";
+  BOOST_REQUIRE_EQUAL(1, utf8::char_length(one_byte));
+  BOOST_REQUIRE_EQUAL(1, utf8::char_length(two_bytes));
+  BOOST_REQUIRE_EQUAL(1, utf8::char_length(three_bytes));
+  BOOST_REQUIRE_EQUAL(1, utf8::char_length(four_bytes));
+  BOOST_REQUIRE_EQUAL(12, utf8::char_length(test_string));
+}
+BOOST_AUTO_TEST_SUITE_END()

